import 'package:flutter/material.dart';

import 'fx_colors.dart';
import 'fx_text.dart';
import 'fx_utils.dart';

class FxDialog extends StatefulWidget {
  final String? imageName;
  final String? title;
  final String? message;
  final String? confirmStr;
  final String? cancelStr;
  final Function()? onConfirm;
  final Function()? onCancel;
  final Widget? customContent;

  const FxDialog(
      {Key? key,
      this.title,
      this.onConfirm,
      this.onCancel,
      required this.message,
      this.cancelStr,
      this.confirmStr,
      this.customContent,
        this.imageName}
        )
      : super(key: key);

  @override
  _FxDialogState createState() => _FxDialogState();

  static Future<T?> show<T>(BuildContext context,
      {String? title,
      Function()? onConfirm,
      Function()? onCancel,
      String? message,
      String? cancelStr,
      String? confirmStr,
      Widget? customContent,
      String? imageName}) {
    return showDialog<T>(
        context: context,
        barrierColor: FXColor.black.withOpacity(0.4),
        builder: (BuildContext context) {
          return FxDialog(
            imageName: imageName,
            title: title,
            message: message,
            confirmStr: confirmStr,
            cancelStr: cancelStr,
            onConfirm: onConfirm,
            onCancel: onCancel,
            customContent: customContent,
          );
        });
  }
}

class _FxDialogState extends State<FxDialog> {
  @override
  Widget build(BuildContext context) {
    return Dialog(
      insetPadding: const EdgeInsets.symmetric(horizontal: 48),
      backgroundColor: FXColor.white,
      elevation: 0,
      shape: RoundedRectangleBorder(borderRadius: BorderRadius.circular(10)),
      child: Column(
        mainAxisSize: MainAxisSize.min,
        children: [
          const SizedBox(height: 20),
          if(!FxUtils.isTextEmpty(widget.imageName))
            Padding(padding: const EdgeInsets.only(left: 24,top: 0,right: 24,bottom: 12),
            child: Image.asset(
              widget.imageName!,
              width: 40,
              height: 40,
            ),),
          if (!FxUtils.isTextEmpty(widget.title))
            Padding(
              padding: const EdgeInsets.only(left: 24, top: 0, right: 24, bottom: 12),
              child: FXText(
                widget.title!,
                style: FXText.content.apply(fontWeightDelta: 2, fontSizeDelta: 2, color: FXColor.color333333),
              ),
            ),
          if (!FxUtils.isTextEmpty(widget.message))
            Padding(
              padding: const EdgeInsets.only(left: 24, top: 0, right: 24, bottom: 20),
              child: Column(
                children: [
                  FXText(widget.message!,
                      textAlign: TextAlign.center,
                      style: widget.imageName != null? FXText.content.apply(fontSizeDelta: -2, color: FXColor.grey5):FXText.content),

                  if (widget.customContent != null) widget.customContent!,
                ],
              ),
            ),
          Container(height: 0.5, color: FXColor.white1),
          IntrinsicHeight(
            child: Row(
              children: [
                if (!FxUtils.isTextEmpty(widget.cancelStr))
                  Expanded(
                    child: GestureDetector(
                      onTap: () {
                        Navigator.pop(context);
                        widget.onCancel?.call();
                      },
                      behavior: HitTestBehavior.opaque,
                      child: Container(
                        alignment: Alignment.center,
                        padding: const EdgeInsets.symmetric(vertical: 16.0),
                        child: FXText(widget.cancelStr!, style: FXText.content.apply(color: FXColor.grey1)),
                      ),
                    ),
                  ),
                if (!FxUtils.isTextEmpty(widget.confirmStr) && !FxUtils.isTextEmpty(widget.cancelStr))
                  Container(width: 0.5, color: FXColor.white1),
                if (!FxUtils.isTextEmpty(widget.confirmStr))
                  Expanded(
                    child: GestureDetector(
                      onTap: () {
                        Navigator.pop(context);
                        widget.onConfirm?.call();
                      },
                      behavior: HitTestBehavior.opaque,
                      child: Container(
                          alignment: Alignment.center,
                          padding: const EdgeInsets.symmetric(vertical: 16.0),
                          child: FXText(widget.confirmStr!, style: FXText.content.apply(color: FXColor.primary))),
                    ),
                  ),
              ],
            ),
          )
        ],
      ),
    );
  }
}
