import 'package:flutter/cupertino.dart';

import 'fx_colors.dart';

/// 修正不同手机上leading和不居中的问题
class FXText extends StatelessWidget {
  final String data;
  final TextStyle style;
  final int? maxLines;
  final double textMaxWidth;
  final TextAlign? textAlign;

  static const content_org = TextStyle(color: FXColor.black1, fontWeight: FontWeight.normal, fontSize: 16);
  static const content = TextStyle(
      color: FXColor.black1,
      fontWeight: FontWeight.normal,
      fontSize: 16,
      height: 1.0,
      leadingDistribution: TextLeadingDistribution.even);
  static var input_hint = content.copyWith(letterSpacing: 0, color: FXColor.grey3, height: 1.5);
  static var subtitle = content.apply(fontSizeDelta: -2);
  static var comment = subtitle.apply(color: FXColor.grey3);
  static var title_black = content.copyWith(fontWeight: FontWeight.w600, fontSize: 18);
  static var title_white = title_black.apply(color: FXColor.white);

  static const _fontSize2HeightMap = {
    11: 19,
    12: 20,
    14: 22,
    16: 24,
    18: 26,
    20: 28,
    28: 36,
    48: 56
  };

  double? _adjustedHeight(TextStyle style) {
    return (_fontSize2HeightMap[style.fontSize] ?? 24) / (style.fontSize ?? 16);
  }

  const FXText(this.data,
      {Key? key, this.style = content, this.maxLines, this.textMaxWidth = double.infinity, this.textAlign})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Text(data,
        maxLines: maxLines,
        textAlign: textAlign,
        style: style,
        strutStyle: StrutStyle(
          fontSize: style.fontSize,
          fontWeight: style.fontWeight,
          height: _adjustedHeight(style),
          forceStrutHeight: true, // 关键属性 强制改为文字高度
        ));
  }
}
